@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -58,7 +58,7 @@ from .type_defs import (
     UpdateResourceShareResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -70,7 +70,7 @@ __all__ = ("RAMClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -102,7 +102,7 @@ class Exceptions:
 
 class RAMClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html)
     """
 
@@ -115,12 +115,13 @@ class RAMClient(BaseClient):
         """
 
     def accept_resource_share_invitation(
-        self, *, resourceShareInvitationArn: str, clientToken: str = None
+        self, *, resourceShareInvitationArn: str, clientToken: str = ...
     ) -> AcceptResourceShareInvitationResponseTypeDef:
         """
-        Accepts an invitation to a resource share from another AWS account.
+        Accepts an invitation to a resource share from another Amazon Web Services
+        account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.accept_resource_share_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#accept_resource_share_invitation)
         """
 
@@ -128,15 +129,15 @@ class RAMClient(BaseClient):
         self,
         *,
         resourceShareArn: str,
-        resourceArns: List[str] = None,
-        principals: List[str] = None,
-        clientToken: str = None
+        resourceArns: Sequence[str] = ...,
+        principals: Sequence[str] = ...,
+        clientToken: str = ...
     ) -> AssociateResourceShareResponseTypeDef:
         """
         Associates the specified resource share with the specified principals and
         resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.associate_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.associate_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate_resource_share)
         """
 
@@ -145,14 +146,14 @@ class RAMClient(BaseClient):
         *,
         resourceShareArn: str,
         permissionArn: str,
-        replace: bool = None,
-        clientToken: str = None,
-        permissionVersion: int = None
+        replace: bool = ...,
+        clientToken: str = ...,
+        permissionVersion: int = ...
     ) -> AssociateResourceSharePermissionResponseTypeDef:
         """
         Associates a permission with a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.associate_resource_share_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#associate_resource_share_permission)
         """
 
@@ -160,7 +161,7 @@ class RAMClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#can_paginate)
         """
 
@@ -168,27 +169,27 @@ class RAMClient(BaseClient):
         self,
         *,
         name: str,
-        resourceArns: List[str] = None,
-        principals: List[str] = None,
-        tags: List["TagTypeDef"] = None,
-        allowExternalPrincipals: bool = None,
-        clientToken: str = None,
-        permissionArns: List[str] = None
+        resourceArns: Sequence[str] = ...,
+        principals: Sequence[str] = ...,
+        tags: Sequence["TagTypeDef"] = ...,
+        allowExternalPrincipals: bool = ...,
+        clientToken: str = ...,
+        permissionArns: Sequence[str] = ...
     ) -> CreateResourceShareResponseTypeDef:
         """
         Creates a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.create_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.create_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#create_resource_share)
         """
 
     def delete_resource_share(
-        self, *, resourceShareArn: str, clientToken: str = None
+        self, *, resourceShareArn: str, clientToken: str = ...
     ) -> DeleteResourceShareResponseTypeDef:
         """
         Deletes the specified resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.delete_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.delete_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#delete_resource_share)
         """
 
@@ -196,25 +197,25 @@ class RAMClient(BaseClient):
         self,
         *,
         resourceShareArn: str,
-        resourceArns: List[str] = None,
-        principals: List[str] = None,
-        clientToken: str = None
+        resourceArns: Sequence[str] = ...,
+        principals: Sequence[str] = ...,
+        clientToken: str = ...
     ) -> DisassociateResourceShareResponseTypeDef:
         """
         Disassociates the specified principals or resources from the specified resource
         share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.disassociate_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.disassociate_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate_resource_share)
         """
 
     def disassociate_resource_share_permission(
-        self, *, resourceShareArn: str, permissionArn: str, clientToken: str = None
+        self, *, resourceShareArn: str, permissionArn: str, clientToken: str = ...
     ) -> DisassociateResourceSharePermissionResponseTypeDef:
         """
-        Disassociates an AWS RAM permission from a resource share.
+        Disassociates an RAM permission from a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.disassociate_resource_share_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#disassociate_resource_share_permission)
         """
 
@@ -222,48 +223,48 @@ class RAMClient(BaseClient):
         self,
     ) -> EnableSharingWithAwsOrganizationResponseTypeDef:
         """
-        Enables resource sharing within your AWS Organization.
+        Enables resource sharing within your organization in Organizations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.enable_sharing_with_aws_organization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#enable_sharing_with_aws_organization)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#generate_presigned_url)
         """
 
     def get_permission(
-        self, *, permissionArn: str, permissionVersion: int = None
+        self, *, permissionArn: str, permissionVersion: int = ...
     ) -> GetPermissionResponseTypeDef:
         """
-        Gets the contents of an AWS RAM permission in JSON format.
+        Gets the contents of an RAM permission in JSON format.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.get_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_permission)
         """
 
     def get_resource_policies(
         self,
         *,
-        resourceArns: List[str],
-        principal: str = None,
-        nextToken: str = None,
-        maxResults: int = None
+        resourceArns: Sequence[str],
+        principal: str = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> GetResourcePoliciesResponseTypeDef:
         """
         Gets the policies for the specified resources that you own and have shared.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_resource_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.get_resource_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_policies)
         """
 
@@ -271,32 +272,32 @@ class RAMClient(BaseClient):
         self,
         *,
         associationType: ResourceShareAssociationTypeType,
-        resourceShareArns: List[str] = None,
-        resourceArn: str = None,
-        principal: str = None,
-        associationStatus: ResourceShareAssociationStatusType = None,
-        nextToken: str = None,
-        maxResults: int = None
+        resourceShareArns: Sequence[str] = ...,
+        resourceArn: str = ...,
+        principal: str = ...,
+        associationStatus: ResourceShareAssociationStatusType = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> GetResourceShareAssociationsResponseTypeDef:
         """
         Gets the resources or principals for the resource shares that you own.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_resource_share_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.get_resource_share_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_share_associations)
         """
 
     def get_resource_share_invitations(
         self,
         *,
-        resourceShareInvitationArns: List[str] = None,
-        resourceShareArns: List[str] = None,
-        nextToken: str = None,
-        maxResults: int = None
+        resourceShareInvitationArns: Sequence[str] = ...,
+        resourceShareArns: Sequence[str] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> GetResourceShareInvitationsResponseTypeDef:
         """
         Gets the invitations that you have received for resource shares.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.get_resource_share_invitations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_share_invitations)
         """
 
@@ -304,40 +305,40 @@ class RAMClient(BaseClient):
         self,
         *,
         resourceOwner: ResourceOwnerType,
-        resourceShareArns: List[str] = None,
-        resourceShareStatus: ResourceShareStatusType = None,
-        name: str = None,
-        tagFilters: List["TagFilterTypeDef"] = None,
-        nextToken: str = None,
-        maxResults: int = None,
-        permissionArn: str = None
+        resourceShareArns: Sequence[str] = ...,
+        resourceShareStatus: ResourceShareStatusType = ...,
+        name: str = ...,
+        tagFilters: Sequence["TagFilterTypeDef"] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...,
+        permissionArn: str = ...
     ) -> GetResourceSharesResponseTypeDef:
         """
         Gets the resource shares that you own or the resource shares that are shared
         with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.get_resource_shares)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.get_resource_shares)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#get_resource_shares)
         """
 
     def list_pending_invitation_resources(
-        self, *, resourceShareInvitationArn: str, nextToken: str = None, maxResults: int = None
+        self, *, resourceShareInvitationArn: str, nextToken: str = ..., maxResults: int = ...
     ) -> ListPendingInvitationResourcesResponseTypeDef:
         """
         Lists the resources in a resource share that is shared with you but that the
         invitation is still pending for.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.list_pending_invitation_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_pending_invitation_resources)
         """
 
     def list_permissions(
-        self, *, resourceType: str = None, nextToken: str = None, maxResults: int = None
+        self, *, resourceType: str = ..., nextToken: str = ..., maxResults: int = ...
     ) -> ListPermissionsResponseTypeDef:
         """
-        Lists the AWS RAM permissions.
+        Lists the RAM permissions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.list_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_permissions)
         """
 
@@ -345,38 +346,38 @@ class RAMClient(BaseClient):
         self,
         *,
         resourceOwner: ResourceOwnerType,
-        resourceArn: str = None,
-        principals: List[str] = None,
-        resourceType: str = None,
-        resourceShareArns: List[str] = None,
-        nextToken: str = None,
-        maxResults: int = None
+        resourceArn: str = ...,
+        principals: Sequence[str] = ...,
+        resourceType: str = ...,
+        resourceShareArns: Sequence[str] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> ListPrincipalsResponseTypeDef:
         """
         Lists the principals that you have shared resources with or that have shared
         resources with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_principals)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.list_principals)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_principals)
         """
 
     def list_resource_share_permissions(
-        self, *, resourceShareArn: str, nextToken: str = None, maxResults: int = None
+        self, *, resourceShareArn: str, nextToken: str = ..., maxResults: int = ...
     ) -> ListResourceSharePermissionsResponseTypeDef:
         """
-        Lists the AWS RAM permissions that are associated with a resource share.
+        Lists the RAM permissions that are associated with a resource share.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.list_resource_share_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resource_share_permissions)
         """
 
     def list_resource_types(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListResourceTypesResponseTypeDef:
         """
-        Lists the shareable resource types supported by AWS RAM.
+        Lists the shareable resource types supported by RAM.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_resource_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.list_resource_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resource_types)
         """
 
@@ -384,18 +385,18 @@ class RAMClient(BaseClient):
         self,
         *,
         resourceOwner: ResourceOwnerType,
-        principal: str = None,
-        resourceType: str = None,
-        resourceArns: List[str] = None,
-        resourceShareArns: List[str] = None,
-        nextToken: str = None,
-        maxResults: int = None
+        principal: str = ...,
+        resourceType: str = ...,
+        resourceArns: Sequence[str] = ...,
+        resourceShareArns: Sequence[str] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> ListResourcesResponseTypeDef:
         """
         Lists the resources that you added to a resource shares or the resources that
         are shared with you.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.list_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.list_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#list_resources)
         """
 
@@ -405,35 +406,38 @@ class RAMClient(BaseClient):
         """
         Resource shares that were created by attaching a policy to a resource are
         visible only to the resource share owner, and the resource share cannot be
-        modified in AWS RAM.
+        modified in RAM.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.promote_resource_share_created_from_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#promote_resource_share_created_from_policy)
         """
 
     def reject_resource_share_invitation(
-        self, *, resourceShareInvitationArn: str, clientToken: str = None
+        self, *, resourceShareInvitationArn: str, clientToken: str = ...
     ) -> RejectResourceShareInvitationResponseTypeDef:
         """
-        Rejects an invitation to a resource share from another AWS account.
+        Rejects an invitation to a resource share from another Amazon Web Services
+        account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.reject_resource_share_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#reject_resource_share_invitation)
         """
 
-    def tag_resource(self, *, resourceShareArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(
+        self, *, resourceShareArn: str, tags: Sequence["TagTypeDef"]
+    ) -> Dict[str, Any]:
         """
         Adds the specified tags to the specified resource share that you own.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceShareArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceShareArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes the specified tags from the specified resource share that you own.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#untag_resource)
         """
 
@@ -441,14 +445,14 @@ class RAMClient(BaseClient):
         self,
         *,
         resourceShareArn: str,
-        name: str = None,
-        allowExternalPrincipals: bool = None,
-        clientToken: str = None
+        name: str = ...,
+        allowExternalPrincipals: bool = ...,
+        clientToken: str = ...
     ) -> UpdateResourceShareResponseTypeDef:
         """
         Updates the specified resource share that you own.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Client.update_resource_share)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Client.update_resource_share)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/client.html#update_resource_share)
         """
 
@@ -457,7 +461,7 @@ class RAMClient(BaseClient):
         self, operation_name: Literal["get_resource_policies"]
     ) -> GetResourcePoliciesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcepoliciespaginator)
         """
 
@@ -466,7 +470,7 @@ class RAMClient(BaseClient):
         self, operation_name: Literal["get_resource_share_associations"]
     ) -> GetResourceShareAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareassociationspaginator)
         """
 
@@ -475,7 +479,7 @@ class RAMClient(BaseClient):
         self, operation_name: Literal["get_resource_share_invitations"]
     ) -> GetResourceShareInvitationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourceshareinvitationspaginator)
         """
 
@@ -484,20 +488,20 @@ class RAMClient(BaseClient):
         self, operation_name: Literal["get_resource_shares"]
     ) -> GetResourceSharesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.GetResourceShares)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Paginator.GetResourceShares)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#getresourcesharespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_principals"]) -> ListPrincipalsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.ListPrincipals)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Paginator.ListPrincipals)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listprincipalspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resources"]) -> ListResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.14/reference/services/ram.html#RAM.Paginator.ListResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/ram.html#RAM.Paginator.ListResources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ram/paginators.html#listresourcespaginator)
         """
