@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     ResourceOwnerType,
@@ -25,7 +25,7 @@ from .literals import (
     ResourceStatusType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -165,8 +165,8 @@ _RequiredAssociateResourceShareRequestRequestTypeDef = TypedDict(
 _OptionalAssociateResourceShareRequestRequestTypeDef = TypedDict(
     "_OptionalAssociateResourceShareRequestRequestTypeDef",
     {
-        "resourceArns": List[str],
-        "principals": List[str],
+        "resourceArns": Sequence[str],
+        "principals": Sequence[str],
         "clientToken": str,
     },
     total=False,
@@ -198,12 +198,12 @@ _RequiredCreateResourceShareRequestRequestTypeDef = TypedDict(
 _OptionalCreateResourceShareRequestRequestTypeDef = TypedDict(
     "_OptionalCreateResourceShareRequestRequestTypeDef",
     {
-        "resourceArns": List[str],
-        "principals": List[str],
-        "tags": List["TagTypeDef"],
+        "resourceArns": Sequence[str],
+        "principals": Sequence[str],
+        "tags": Sequence["TagTypeDef"],
         "allowExternalPrincipals": bool,
         "clientToken": str,
-        "permissionArns": List[str],
+        "permissionArns": Sequence[str],
     },
     total=False,
 )
@@ -297,8 +297,8 @@ _RequiredDisassociateResourceShareRequestRequestTypeDef = TypedDict(
 _OptionalDisassociateResourceShareRequestRequestTypeDef = TypedDict(
     "_OptionalDisassociateResourceShareRequestRequestTypeDef",
     {
-        "resourceArns": List[str],
-        "principals": List[str],
+        "resourceArns": Sequence[str],
+        "principals": Sequence[str],
         "clientToken": str,
     },
     total=False,
@@ -361,7 +361,7 @@ GetPermissionResponseTypeDef = TypedDict(
 _RequiredGetResourcePoliciesRequestRequestTypeDef = TypedDict(
     "_RequiredGetResourcePoliciesRequestRequestTypeDef",
     {
-        "resourceArns": List[str],
+        "resourceArns": Sequence[str],
     },
 )
 _OptionalGetResourcePoliciesRequestRequestTypeDef = TypedDict(
@@ -400,7 +400,7 @@ _RequiredGetResourceShareAssociationsRequestRequestTypeDef = TypedDict(
 _OptionalGetResourceShareAssociationsRequestRequestTypeDef = TypedDict(
     "_OptionalGetResourceShareAssociationsRequestRequestTypeDef",
     {
-        "resourceShareArns": List[str],
+        "resourceShareArns": Sequence[str],
         "resourceArn": str,
         "principal": str,
         "associationStatus": ResourceShareAssociationStatusType,
@@ -430,8 +430,8 @@ GetResourceShareAssociationsResponseTypeDef = TypedDict(
 GetResourceShareInvitationsRequestRequestTypeDef = TypedDict(
     "GetResourceShareInvitationsRequestRequestTypeDef",
     {
-        "resourceShareInvitationArns": List[str],
-        "resourceShareArns": List[str],
+        "resourceShareInvitationArns": Sequence[str],
+        "resourceShareArns": Sequence[str],
         "nextToken": str,
         "maxResults": int,
     },
@@ -456,10 +456,10 @@ _RequiredGetResourceSharesRequestRequestTypeDef = TypedDict(
 _OptionalGetResourceSharesRequestRequestTypeDef = TypedDict(
     "_OptionalGetResourceSharesRequestRequestTypeDef",
     {
-        "resourceShareArns": List[str],
+        "resourceShareArns": Sequence[str],
         "resourceShareStatus": ResourceShareStatusType,
         "name": str,
-        "tagFilters": List["TagFilterTypeDef"],
+        "tagFilters": Sequence["TagFilterTypeDef"],
         "nextToken": str,
         "maxResults": int,
         "permissionArn": str,
@@ -544,9 +544,9 @@ _OptionalListPrincipalsRequestRequestTypeDef = TypedDict(
     "_OptionalListPrincipalsRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "principals": List[str],
+        "principals": Sequence[str],
         "resourceType": str,
-        "resourceShareArns": List[str],
+        "resourceShareArns": Sequence[str],
         "nextToken": str,
         "maxResults": int,
     },
@@ -630,8 +630,8 @@ _OptionalListResourcesRequestRequestTypeDef = TypedDict(
     {
         "principal": str,
         "resourceType": str,
-        "resourceArns": List[str],
-        "resourceShareArns": List[str],
+        "resourceArns": Sequence[str],
+        "resourceShareArns": Sequence[str],
         "nextToken": str,
         "maxResults": int,
     },
@@ -842,7 +842,7 @@ TagFilterTypeDef = TypedDict(
     "TagFilterTypeDef",
     {
         "tagKey": str,
-        "tagValues": List[str],
+        "tagValues": Sequence[str],
     },
     total=False,
 )
@@ -851,7 +851,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceShareArn": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -868,7 +868,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceShareArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
